[Python-checkins] r57206 - sandbox/trunk/import_in_py/tests/test_fs_loader.py

brett.cannon python-checkins at python.org
Mon Aug 20 03:02:28 CEST 2007


Author: brett.cannon
Date: Mon Aug 20 03:02:22 2007
New Revision: 57206

Modified:
   sandbox/trunk/import_in_py/tests/test_fs_loader.py
Log:
Add more test stubs.  Also clear up in tests exactly what needs to be tested.


Modified: sandbox/trunk/import_in_py/tests/test_fs_loader.py
==============================================================================
--- sandbox/trunk/import_in_py/tests/test_fs_loader.py	(original)
+++ sandbox/trunk/import_in_py/tests/test_fs_loader.py	Mon Aug 20 03:02:22 2007
@@ -124,24 +124,31 @@
         TestPyPycPackages.setUp(self, faked_names=False)
 
     def test_pyc_over_py(self):
-        # If a bytecode file is good, don't even bother with the source.
+        # If a bytecode file is good, don't even bother with the source
+        # (top-level or package).
         raise NotImplementedError
 
     def test_only_good_pyc(self):
-        # Should be able to load even if only bytecode is available.
+        # Should be able to load even if only bytecode is available (top-level
+        # or package).
         raise NotImplementedError
 
     def test_only_py(self):
-        # Having only source should be fine.
+        # Having only source should be fine (top-level or package).
         raise NotImplementedError
 
     def test_stale_pyc(self):
-        # If a bytecode file is stale, regenerate it and use the source.
+        # If a bytecode file is stale then an exception is raised (no source),
+        # or the source is used and the bytecode is regenerated.
         raise NotImplementedError
 
     def test_bad_magic(self):
-        # If the magic cookie for bytecode is bad, use the source and
-        # regenerate the bytecode.
+        # If the magic cookie for bytecode is bad then raise an exception (no
+        # source), or regenerate the bytecode.
+        raise NotImplementedError
+
+    def test_malformed_bytecode(self):
+        # Invalid bytecode triggers an exception, source or not.
         raise NotImplementedError
 
 


More information about the Python-checkins mailing list